Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(196)

Unified Diff: components/web_view/web_view_impl.h

Issue 1340983002: Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/web_view/web_view_apptest.cc ('k') | components/web_view/web_view_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/web_view/web_view_impl.h
diff --git a/components/web_view/web_view_impl.h b/components/web_view/web_view_impl.h
index 2c50bbae32613830c62917a438fb51f4f71cdaa8..ac5e609fd7a9a9f81326bf76e96f8be34e5ff630 100644
--- a/components/web_view/web_view_impl.h
+++ b/components/web_view/web_view_impl.h
@@ -29,8 +29,8 @@ class PendingWebViewLoad;
class URLRequestCloneable;
class WebViewImpl : public mojom::WebView,
- public mojo::ViewTreeDelegate,
- public mojo::ViewObserver,
+ public mus::ViewTreeDelegate,
+ public mus::ViewObserver,
public FrameTreeDelegate,
public FrameDevToolsAgentDelegate {
public:
@@ -58,15 +58,15 @@ class WebViewImpl : public mojom::WebView,
void GoBack() override;
void GoForward() override;
- // Overridden from mojo::ViewTreeDelegate:
- void OnEmbed(mojo::View* root) override;
- void OnConnectionLost(mojo::ViewTreeConnection* connection) override;
+ // Overridden from mus::ViewTreeDelegate:
+ void OnEmbed(mus::View* root) override;
+ void OnConnectionLost(mus::ViewTreeConnection* connection) override;
- // Overridden from mojo::ViewObserver:
- void OnViewBoundsChanged(mojo::View* view,
+ // Overridden from mus::ViewObserver:
+ void OnViewBoundsChanged(mus::View* view,
const mojo::Rect& old_bounds,
const mojo::Rect& new_bounds) override;
- void OnViewDestroyed(mojo::View* view) override;
+ void OnViewDestroyed(mus::View* view) override;
// Overridden from FrameTreeDelegate:
bool CanPostMessageEventToFrame(const Frame* source,
@@ -86,8 +86,8 @@ class WebViewImpl : public mojom::WebView,
mojo::ApplicationImpl* app_;
mojom::WebViewClientPtr client_;
mojo::StrongBinding<WebView> binding_;
- mojo::View* root_;
- mojo::View* content_;
+ mus::View* root_;
+ mus::View* content_;
scoped_ptr<FrameTree> frame_tree_;
// When LoadRequest() is called a PendingWebViewLoad is created to wait for
« no previous file with comments | « components/web_view/web_view_apptest.cc ('k') | components/web_view/web_view_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698